import graphicsclass, inputclass, shipclass, worldclass, math, soundclass
from verletropeclass import *
from constants import *

class maingame:
	def __init__(self, graphics, inputs, sounds):
		self.world = worldclass.world(graphics)
		self.graphics = graphics
		self.input = inputs
		self.sounds = sounds
		self.string = Rope((50950,self.world.checkfloor(50950)-33),(50950+100,self.world.checkfloor(50950)-133), 15, gravity, timeStep)
		#self.string.masses[len(self.string.masses)-1].m = 5
		self.ship = shipclass.playership(51050, self.world.checkfloor(51050), gravity, graphics, inputs, self.world)
#		print self.ship.pos
		self.acc = 0
		self.graphics.load('crate.bmp','crate', True, [0,0,0])
		self.graphics.load('stars.bmp','stars')
		self.graphics.load('rightarrow.bmp','rightarrow', True, [0,0,0])
		self.graphics.load('leftarrow.bmp','leftarrow', True, [0,0,0])
		self.graphics.load('downarrow.bmp','downarrow', True, [0,0,0])
		self.carrying = None
		self.money = 0
		self.score = 0
		self.paused = False
	def draw(self):
		centerx = self.string.oldparticles[0][0] + (self.string.particles[0][0] - self.string.oldparticles[0][0]) * self.acc/timeStep
		for x in range(3):
			self.graphics.draw('stars', (x*512 - centerx/4 % 512,0))
			self.graphics.draw('stars', (x*512 - centerx/4 % 512,512))
		self.world.draw(self.graphics,centerx)
		if self.ship.strength > 0:
			self.string.draw(self.graphics, self.acc)	#we pass the accumulator value in, so that we can go between the previous position and the new position the correct amount, to make a smooth transition
		#self.graphics.write('inf
		if self.carrying != None:
			if self.carrying.strength > 0:
				
				x = self.string.oldparticles[-1][0] + (self.string.particles[-1][0] - self.string.oldparticles[-1][0]) * self.acc/timeStep
				y = self.string.oldparticles[-1][1] + (self.string.particles[-1][1] - self.string.oldparticles[-1][1]) * self.acc/timeStep
				self.graphics.draw('crate', (x-self.string.centerx + halfwindowsize[0]-25,y-25))
				if self.carrying.droppoint - centerx > halfwindowsize[0]:
					self.graphics.draw('rightarrow', (windowSize[0] - 70, 200))
					self.graphics.write('info',str(abs(int(self.carrying.droppoint - centerx))), (windowSize[0]-70, 230),(255,255,255), False)
				elif self.carrying.droppoint-centerx < -halfwindowsize[0]:
					self.graphics.draw('leftarrow', (10, 200))
					self.graphics.write('info',str(abs(int(self.carrying.droppoint - centerx))), (40, 230),(255,255,255), False)
				else:
					self.graphics.draw('downarrow', (self.carrying.droppoint-centerx + halfwindowsize[0] -25, self.world.checkfloor(self.carrying.droppoint)-60))
					if self.string.particles[-1][0] < self.carrying.droppoint+40 and self.string.particles[-1][0] > self.carrying.droppoint-40 and self.string.particles[-1][1] > self.world.checkfloor(self.carrying.droppoint)-40:	#ok, this is when we get the box to it's destination
						self.money += self.carrying.price
						self.score += self.carrying.price
						self.carrying.__init__()
						self.carrying = None
						self.string.setmass(ropepartmass)
						self.sounds.play('drop')
			else:	#package has been destroyed
				self.money -= self.carrying.price * 2
				if self.money < 0:
					self.money = 0
				self.carrying.__init__()
				self.carrying = None
				self.string.setmass(ropepartmass)
				
		result = self.ship.draw(self.string, self.acc, self.sounds)	#it's stupid but the sounds for the engine are done here
		#now draw the HUD:
		self.graphics.write('info', 'Shield', (10,10), (255,255,255), False)
		self.graphics.drawrect((255,0,0), (60,10,100*(self.ship.strength / self.ship.maxstrength),10))
		self.graphics.write('info', 'Fuel ', (10,25), (255,255,255), False)
		self.graphics.drawrect((255,255,0), (60,25,100*(self.ship.fuel / self.ship.maxfuel),10))
		if self.carrying != None:
			self.graphics.write('info', 'Package ', (10,40), (255,255,255), False)
			self.graphics.drawrect((255,0,255), (60,40,100*(self.carrying.strength / self.carrying.maxstrength),10))	
		self.graphics.write('big', str(int(self.money)), (halfwindowsize[0], 30), (255,255,255), True)
		self.graphics.write('info', 'Score: '+str(int(self.score)), (windowSize[0]-100, 10), (255,255,255), False)
		return result
		
	def go(self, dt):
		#self.ship.go(dt)
		#self.string.particles[0][0] = self.ship.pos[0]
		#self.string.particles[0][1] = self.ship.pos[1]
		#print(1/dt)
		if self.paused == False:
			self.acc += dt
			if self.acc >= timeStep:
				while self.acc >= timeStep:
					self.string.dotimestep(self.ship, self.input, self.world, self.carrying, self, self.sounds)
					self.acc -= timeStep
			for each in self.world.packagesonscreen:
				if self.carrying == None:
					x = each.pickuppoint
					y = self.world.checkfloor(x)
					if self.string.particles[-1][0] < x+25 and self.string.particles[-1][0] > x-25 and self.string.particles[-1][1] > y-25:
						each.state = 1
						self.carrying = each
						self.string.setmass(each.mass)
						self.sounds.play('pickup')
			if self.input.keys['escape'] == True:
				self.paused = True
				self.input.keys['escape'] = False
		else:
			if self.input.keys['escape'] == True:
				self.paused = False
				self.input.keys['escape'] = False
		#print dt
		if self.draw() == 0:
			gs = GSMain
		else:
			gs = GSEnd
			self.sounds.stop('thrust')
			
		return gs
